@@ -1,5 +1,5 @@
 from HABApp.openhab.items.base_item import OpenhabItem
-from HABApp.openhab.definitions.commands import OnOffCommand, PercentCommand
+from HABApp.openhab.items.commands import OnOffCommand, PercentCommand
 from ..definitions import OnOffValue, PercentValue
 
 
