@@ -1,5 +1,5 @@
 import typing
-from ..core.const.json import load_json
+from HABApp.core.const.json import load_json
 
 from .events import OpenhabEvent, \
     ItemStateEvent, ItemStateChangedEvent, ItemCommandEvent, ItemAddedEvent, \
@@ -23,7 +23,7 @@ __event_lookup: typing.Dict[str, typing.Type[OpenhabEvent]] = {k.__name__: k for
 __event_lookup['ConfigStatusInfoEvent'] = ThingConfigStatusInfoEvent    # Naming from openhab is inconsistent here
 
 
-def get_event(_in_dict : dict) -> OpenhabEvent:
+def get_event(_in_dict: dict) -> OpenhabEvent:
     event_type: str = _in_dict['type']
     topic: str = _in_dict['topic']
 
