@@ -1,7 +1,8 @@
-from .timeframe import TimeFrame
-
 from .counter_item import CounterItem
 from .period_counter import PeriodCounter
 from .threshold import Threshold
 from .statistics import Statistics
-from .multimode_item import MultiModeItem
+from . import multimode
+
+# 27.04.2020 - this can be removed in some time
+from .multimode import MultiModeItem
